@@ -42,7 +42,7 @@ use G::Messenger;
 use G::Inspire;
 
 # import core modules
-require G::DynamicLoader;
+use G::DynamicLoader;
 
 # import db classes
 use G::DB::SDB;
@@ -158,7 +158,6 @@ push(@EXPORT, @G::Messenger::EXPORT);
 # export plugin functions (overrides all)
 push(@EXPORT, @G::DynamicLoader::EXPORT);
 
-
 our $VERSION = $G::IO::VERSION;
 
 mkdir($ENV{HOME} . '/.glang/data/');
@@ -577,6 +576,16 @@ G - G-language Genome Analysis Environment core interface module
 
 =cut
 
+=head2 $gb->disable_pseudogenes()
+
+   Name: $gb->disable_pseudogenes()   -   turns all pseudogenes off
+
+   Description:
+         Turns off all pseudogenes by setting $genome->{$feature}->{on}
+         to 0 when $genome->{$feature}->{pseudo} is true.
+
+=cut
+
 =head2 $gb->next_feature()
 
    Name: $gb->next_feature()   -   get the next feature ID
@@ -884,7 +893,8 @@ G - G-language Genome Analysis Environment core interface module
    Description:
          Returns a G instance starting at given position, assuming circular
          chromosome. All information, including the sequence and feature 
-         annotations are moved. 
+         annotations are moved. Note that the given position is Perl position
+         and NOT GenBank position. GenBank position -1 equals Perl position.
 
    Usage:
       $new = $gb->relocate_origin($position);
