@@ -43,7 +43,7 @@ require G::IO::EmblI;
 use File::Basename;
 use File::ShareDir ':ALL';
 
-our $VERSION = '1.8.3';
+our $VERSION = '1.8.4';
 
 #::::::::::::::::::::::::::::::
 #          Perldoc
@@ -231,12 +231,15 @@ sub new {
 	*GENBANK = $this->open_gb($filename);
 
 	if ($multiple_locus){
-	    $this = new G::IO("blessed");
-	    $tmp = new G::IO($filename, "no msg", $format, "no cache");
-	    $this->multi_locus($tmp);
+	    my $tmp = $this->clone();
+	    undef(%$this);
 
-	    set_gene_aliases($this);
+#	    $this = new G::IO("blessed");
+#	    my $tmp = new G::IO($filename, "no msg", $format, "no cache");
 
+	    multi_locus($this, $tmp);
+	    
+	    $this->set_gene_aliases();
 	    $this->seq_info() unless($no_msg);
 	}else{
 	    if ($without_annotation){
@@ -253,8 +256,6 @@ sub new {
 	    }else{
 		$this->next_locus($no_msg);
 
-		set_gene_aliases($this);
-
 		if($force_cache || $no_cache == 0){
 		    sdb_save($this, sprintf("cache-%s-%s-%s", $basename, $stat[7], $stat[9]));
 		}
@@ -432,22 +433,22 @@ sub multi_locus{
     my $this = shift;
     my $gb = shift;
     my $lng;
-    my $i = 1;
+    my $i = 0;
     my $f = 1;
     my $c = 1;
-
+    
     do{
         my $F = 1;
         $lng = length($this->{"SEQ"});
-        $this->{"LOCUS$i"} = $gb->{"LOCUS"};
-        $this->{"HEADER$i"} = $gb->{"HEADER"};
+        $this->{"LOCUS$i"}   = $gb->{"LOCUS"};
+        $this->{"HEADER$i"}  = $gb->{"HEADER"};
         $this->{"COMMENT$i"} = $gb->{"COMMENT"};
 
-        while(defined (%{$gb->{"FEATURE$F"}})){
-            $this->{"FEATURE$f"}            = $gb->{"FEATURE$F"};
-            $this->{"FEATURE$f"}->{"start"} = $gb->{"FEATURE$F"}->{"start"} + $lng;
-            $this->{"FEATURE$f"}->{"end"}   = $gb->{"FEATURE$F"}->{"end"} + $lng;
-            $this->{"FEATURE$f"}->{"locus"} = $i;
+        while(exists($gb->{"FEATURE$F"})){
+            $this->{"FEATURE$f"}              = $gb->{"FEATURE$F"};
+            $this->{"FEATURE$f"}->{"start"}   = $gb->{"FEATURE$F"}->{"start"} + $lng;
+            $this->{"FEATURE$f"}->{"end"}     = $gb->{"FEATURE$F"}->{"end"} + $lng;
+            $this->{"FEATURE$f"}->{"locus"}   = $i;
 	    $this->{"FEATURE$f"}->{"feature"} = $f;
 
 	    if($gb->{"FEATURE$F"}->{"type"} eq "CDS"){
@@ -478,13 +479,12 @@ sub multi_locus{
 
     }while($gb->next_locus("no msg"));
 
-    $this->{"FEATURE0"}->{"type"} = "source";
+    $this->{"FEATURE0"}->{"type"}  = "source";
     $this->{"FEATURE0"}->{"start"} = 1;
-    $this->{"FEATURE0"}->{"end"} = length($this->{"SEQ"});
-    $this->{"LOCUS"} = $this->{"LOCUS1"};
-    $this->{"HEADER"} = $this->{"HEADER1"};
+    $this->{"FEATURE0"}->{"end"}   = length($this->{"SEQ"});
+    $this->{"LOCUS"}   = $this->{"LOCUS1"};
+    $this->{"HEADER"}  = $this->{"HEADER1"};
     $this->{"COMMENT"} = $this->{"COMMENT1"};
-    $this->{"CDS0"}->{dummy} = 1;
 }
 
 
