@@ -38,7 +38,6 @@ use G::DB::SDB;
 #    Variables
 #::::::::::::::::::::::::::::::
 
-my %gene2idHash = ();
 my %feat2idHash = ();
 my $intergenic = 0;
 
@@ -167,12 +166,7 @@ sub getseq {
 }
 
 sub get_gbkseq {
-    my $this = shift;
-    my $start = shift;
-    my $end = shift;
-    my $option = shift;
-
-    return getseq($this, $start - 1, $end - 1, $option);
+    return getseq($_[0], $_[1] - 1, $_[2] - 1, $_[3]);
 }
 
 sub get_cdsseq {
@@ -229,15 +223,9 @@ sub before_startcodon {
     my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
-	return 
-	    complement(substr($this->{SEQ}, 
-			      $this->{$object}->{end}, 
-			      $length));
+	return complement(substr($this->{SEQ}, $this->{$object}->{end}, $length));
     }else{
-	return 
-	    substr($this->{SEQ}, 
-		   $this->{$object}->{start} - 1 - $length, 
-		   $length);
+	return substr($this->{SEQ}, $this->{$object}->{start} - 1 - $length, $length);
     }
 }
 
@@ -247,15 +235,9 @@ sub after_startcodon {
     my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
-	return 
-	    complement(substr($this->{SEQ}, 
-			      $this->{$object}->{end} - 1 - 3 - $length + 1, 
-			      $length));
+	return complement(substr($this->{SEQ}, $this->{$object}->{end} - 1 - 3 - $length + 1, $length));
     }else{
-	return 
-	    substr($this->{SEQ}, 
-		   $this->{$object}->{start} + 3 - 1, 
-		   $length);
+	return substr($this->{SEQ}, $this->{$object}->{start} + 3 - 1, $length);
     }
 }
 
@@ -265,15 +247,9 @@ sub before_stopcodon {
     my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
-	return 
-	    complement(substr($this->{SEQ}, 
-			      $this->{$object}->{start} + 3 - 1, 
-			      $length));
+	return complement(substr($this->{SEQ}, $this->{$object}->{start} + 3 - 1, $length));
     }else{
-	return 
-	    substr($this->{SEQ}, 
-		   $this->{$object}->{end} - 3 - 1 - $length + 1, 
-		   $length);
+	return substr($this->{SEQ}, $this->{$object}->{end} - 3 - 1 - $length + 1, $length);
     }
 }
 
@@ -283,30 +259,18 @@ sub after_stopcodon {
     my $length = shift || 100;
 
     if ($this->{$object}->{direction} eq 'complement'){
-	return 
-	    complement(substr($this->{SEQ}, 
-			      $this->{$object}->{start} - 1 - $length, 
-			      $length));
+	return complement(substr($this->{SEQ}, $this->{$object}->{start} - 1 - $length, $length));
     }else{
-	return 
-	    substr($this->{SEQ}, 
-		   $this->{$object}->{end} +1 - 1, 
-		   $length);
+	return substr($this->{SEQ}, $this->{$object}->{end} +1 - 1, $length);
     }
 }
 
 sub startcodon {
-    my $this = shift;
-    my $object = shift;
-
-    return substr($this->get_geneseq($object), 0, 3);
+    return substr($_[0]->get_geneseq($_[1]), 0, 3);
 }
 
 sub stopcodon {
-    my $this = shift;
-    my $object = shift;
-
-    return substr($this->get_geneseq($object), -3, 3);
+    return substr($_[0]->get_geneseq($_[0]), -3, 3);
 }
 
 sub pos2feature {
@@ -325,17 +289,7 @@ sub pos2feature {
 }
 
 sub gene2id {
-    my $this = shift;
-    my $gene = shift;
-
-    unless(scalar(%gene2idHash)){
-	foreach my $feat ($this->cds()){
-	    $gene2idHash{$this->{$feat}->{gene}} = $feat;
-	    $gene2idHash{$this->{$feat}->{locus_tag}} = $feat;
-	}
-    }
-	   
-    return $gene2idHash{$gene};
+    return 'FEATURE' . $_[0]->{$_[1]}->{feature};
 }
 
 sub feature2id {
@@ -424,6 +378,7 @@ sub get_exon {
 
 sub seq_info {
     my $this = shift;
+
     my $length = length($this->{SEQ});
 
     my $a = $this->{SEQ} =~ tr/a/a/;
@@ -433,40 +388,33 @@ sub seq_info {
     my $others = $length - $a - $t - $g - $c;
     my $msg;
 
-    $msg .= sprintf "\n\nAccession Number: %s\n", $this->{LOCUS}->{id};
+    msg_send(sprintf "\n\nAccession Number: %s\n", $this->{LOCUS}->{id}) if(length($this->{LOCUS}->{id}));
     $msg .= sprintf "\n  Length of Sequence : %9d\n" , $length;
 
     if($others > $a + $t + $g + $c){
-	$msg .= sprintf "\n  This is Amino Acid Sequence\n\n";
+        $msg .= sprintf "\n  This is Amino Acid Sequence. Try amino_info().\n\n";
     }else{
-	$msg .= sprintf "           A Content : %9d (%.2f", 
-	$a , $a / $length * 100;
-	$msg .= "\%)\n";
-	$msg .= sprintf "           T Content : %9d (%.2f", 
-	$t , $t / $length * 100;
-	$msg .= "\%)\n";
-	$msg .= sprintf "           G Content : %9d (%.2f", 
-	$g , $g / $length * 100;
-	$msg .= "\%)\n";
-	$msg .= sprintf "           C Content : %9d (%.2f", 
-	$c , $c / $length * 100;
-	$msg .= "\%)\n";
-	$msg .= sprintf "              Others : %9d (%.2f", 
-	$others,  $others / $length * 100;
-	$msg .= "\%)\n";
-	$msg .= sprintf "          AT Content :    %.2f",
-	($a + $t) / $length * 100;
-	$msg .= "\%\n";
-	$msg .= sprintf "          GC Content :    %.2f", 
-	($g + $c) / $length * 100;
-	$msg .= "\%\n\n";
+        $msg .= sprintf "           A Content : %9d (%.2f\%)\n" , $a , $a / $length * 100;
+        $msg .= sprintf "           T Content : %9d (%.2f\%)\n" , $t , $t / $length * 100;
+        $msg .= sprintf "           G Content : %9d (%.2f\%)\n" , $g , $g / $length * 100;
+        $msg .= sprintf "           C Content : %9d (%.2f\%)\n" , $c , $c / $length * 100;
+        $msg .= sprintf "              Others : %9d (%.2f\%)\n" , $others,  $others / $length * 100;
+        $msg .= sprintf "          AT Content :    %.2f\%\n"    , ($a + $t) / $length * 100;
+        $msg .= sprintf "          GC Content :    %.2f\%\n\n"  , ($g + $c) / $length * 100;
     }
-
     &msg_send($msg);
 
     return ($a, $t, $g, $c);
 }
 
+sub disable_pseudogenes {
+    my $this = shift;
+
+    foreach my $feature ($this->feature()){
+	$this->{$feature}->{on} = 0 if ($this->{$feature}->{pseudo});
+    }
+}
+
 sub feature {
     my $this = shift;
     my $type  = shift;
@@ -498,31 +446,19 @@ sub feature {
 }
 
 sub rRNA {
-    my $this = shift;
-    my $opt = shift;
-
-    return feature($this, 'rRNA', $opt);
+    return feature($_[0], 'rRNA', $_[1]);
 }
 
 sub tRNA {
-    my $this = shift;
-    my $opt = shift;
-
-    return feature($this, 'tRNA', $opt);
+    return feature($_[0], 'tRNA', $_[1]);
 }
 
 sub gene {
-    my $this = shift;
-    my $opt = shift;
-
-    return feature($this, 'gene', $opt);
+    return feature($_[0], 'gene', $_[1]);
 }
 
 sub cds {
-    my $this = shift;
-    my $opt = shift;
-
-    return feature($this, 'CDS', $opt);
+    return feature($_[0], 'CDS', $_[1]);
 }
 
 
@@ -572,17 +508,11 @@ sub previous_feature{
 }
 
 sub next_cds{
-    my $this = shift;
-    my $feature = shift;
-
-    return next_feature($this, $feature, 'CDS');
+    return next_feature($_[0], $_[1], 'CDS');
 }
 
 sub previous_cds{
-    my $this = shift;
-    my $feature = shift;
-
-    return previous_feature($this, $feature, 'CDS');
+    return previous_feature($_[0], $_[1], 'CDS');
 }
 
 sub intergenic {
@@ -659,11 +589,18 @@ sub set_intergenic{
 
 
 sub seq{
-    my $this = shift;
-
-    return $this->{SEQ};
+    return $_[0]->{SEQ};
 }
 
+sub hairpin_cut {
+    system('firefox http://www.toychan.net/afro/');
+    return "\n==============\n!!!Afro Man!!!===============\n\n";
+}
+
+sub del_key {
+    $_[0]->{$_[1]}->{on} = 0;
+    return 1;
+}
 
 
 sub relocate_origin{
@@ -815,25 +752,6 @@ sub reverse_strand{
 
 
 
-
-sub hairpin_cut {
-    my $nuc = shift;
-    my $val = "\n==============\n!!!Afro Man!!!===============\n\n";
-
-    system('firefox http://www.toychan.net/afro/');
-
-    return $val;
-}
-
-sub del_key {
-    my $this = shift;
-    my $key = shift;
-
-    $this->{$key}->{on} = 0;
-
-    return 1;
-}
-
 1;
 
 
