@@ -29,6 +29,7 @@ package G::Seq::Primitive;
 use strict;
 use base qw(Exporter);
 use autouse 'Algorithm::Numerical::Shuffle'=>qw(shuffle);
+use autouse 'G::Seq::PatSearch'=>qw(oligomer_counter);
 use SelfLoader;
 
 use SubOpt;
@@ -221,36 +222,151 @@ sub to_fasta{
 
 =head2 shuffleseq
 
-  Name: shuffleseq   -   create randomized sequence with conserved composition
+  Name: shuffleseq   -   create randomized sequence with conserved k-mer composition
 
   Description:
     Shuffle and randomize the given sequence, conserving the nucleotide/peptide
-    content of the original sequence. Fisher-Yates Algorithm is used for shuffling.
+    k-mer content of the original sequence. 
+
+    For k=1, i.e. shuffling sequencing preserving single nucleotide composition, 
+    Fisher-Yates Algorithm is employed. 
+
+    For k>1, shuffling preserves all k-mers (all k where k=1~k). For example,
+    k=3 preserves all triplet, doublet, and single nucleotide composition. 
+    Algorithm for k-mer preserved shuffling is non-trivial, which is solved
+    by graph theoretical approach with Eulerian random walks in the graph of 
+    k-1-mers. See references 3-5 for details of this algorithm. 
     
   Usage:
     $shuffled_seq = shuffleseq($gb);
 
   Options:
-    None.
+    -k            k-mer to preserve the composition (default: 1)
+                  k=1 means only the base composition is preserved and the 
+                  order is shuffled. k=1 preserves dinucleotide composition
+                  as well as the single nucleotide composotion. Similarly,
+                  k=n preserves all of 1~n -mers. Note that k < 5
+                  with nucleotide sequence will take several minutes to 
+                  finish. 
 
   References:
     1. Fisher R.A. and Yates F. (1938) "Example 12", Statistical Tables, London
     2. Durstenfeld R. (1964) "Algorithm 235: Random permutation", CACM 7(7):420
-  
+    3. Jiang M., Anderson J., Gillespie J., and Mayne M. (2008) "uShuffle: 
+       a useful ool for shuffling biological sequences while preserving the k-let
+       counts", BMC Bioinformatics 9:192
+    4. Kandel D., Matias Y., Unver R., and Winker P. (1996) "Shuffling biological 
+       sequences", Discrete Applied Mathematics 71(1-3):171-185  
+    5. Propp J.G. and Wilson D.B. (1998) "How to get a perfectly random sample 
+       "from a generic Markov chain and generate a random spanning tree of a 
+       directed graph", Journal of Algorithms 27(2):170-217
+
   Author:
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20080421-01 added k-mer count preservation option
     20070612-01 initial posting
 
 =cut
 
 
 sub shuffleseq{
+    opt_default("k"=>1);
     my @args = SubOpt::opt_get(@_);
     my $gb = SubOpt::opt_as_gb(shift @args);
+    my $k = opt_val("k");
 
-    return join('', shuffle(split(//, $gb->{SEQ})));
+    if($k == 1){
+	return join('', shuffle(split(//, $gb->{SEQ})));
+    }
+
+    my $graph = {};
+    my $revgraph = {};
+    my $arborescence = {};
+
+    my $length = length($gb->{SEQ});
+    my %oligo = oligomer_counter($gb, -length=>$k);
+    
+    foreach my $nuc (keys %oligo){
+	$graph->{substr($nuc, 0, $k - 1)}->{substr($nuc, -1, 1)} = $oligo{$nuc};
+	$revgraph->{substr($nuc, 1, $k - 1)}->{substr($nuc, 0, 1)} = $oligo{$nuc};
+    }
+    my $numoligos = keys(%$graph);
+    undef %oligo;
+
+
+    msg_error("Compiling arborescene...\n");
+    
+    my %edged;
+    my $count = 1;
+    $edged{substr($gb->{SEQ}, - ($k - 1))} ++;
+    my %visited = %edged;
+
+    while($numoligos > $count){
+	my @keys = keys %edged;
+	my $node = $keys[int(rand(@keys))];
+	my @nucs = keys %{$revgraph->{$node}};
+	my $rnuc = $nucs[int(rand(@nucs))];
+
+	my $newnode = $rnuc . substr($node, 0, $k - 2);
+	unless($visited{$newnode}){
+	    $count ++;
+	    my $first = substr($node, -1, 1);
+	    $visited{$newnode} ++;
+	    $edged{$newnode} ++;
+	    $arborescence->{$newnode} = $first;
+	    $graph->{$newnode}->{$first} --;
+	}
+	delete($revgraph->{$node}->{$rnuc});
+	delete($edged{$node}) if(scalar(@nucs) == 1);
+    }
+    undef $revgraph;
+
+    msg_error("Compilation of arborescence finished.\nNow generating shuffled sequence.\n");
+
+    my $seed = substr($gb->{SEQ}, 0, $k - 1);
+    my $seq = $seed;
+
+    while(length($seq) < $length){
+	my $num = 0;
+	foreach my $val (values %{$graph->{$seed}}){
+	    $num += $val;
+	}
+	if ($num < 1){
+	    if(defined $arborescence->{$seed}){
+		my $oldseed = $seed;
+
+		$seq .= $arborescence->{$seed};
+		$seed = substr($seed, 1) . $arborescence->{$seed};
+
+		delete($arborescence->{$oldseed});
+
+		next;
+	    }else{
+		die("Dead end: failed to trace the Eulerian. Try shuffling again.");
+		#Mathematically, this should not happen.
+	    }
+	}
+
+	my $rand = int(rand($num));
+	foreach my $key (keys %{$graph->{$seed}}){
+	    if($rand <= $graph->{$seed}->{$key}){
+		$graph->{$seed}->{$key} --;
+		delete($graph->{$seed}->{$key}) if($graph->{$seed}->{$key} < 1);
+		
+		$seed = substr($seed, 1) . $key;
+		$seq .= $key;
+		    
+		last;
+	    }else{
+		$rand -= $graph->{$seed}->{$key};
+	    }
+	}
+    }
+
+    msg_error("Done.\n");
+    return $seq;
 }
 
 
