@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: ReL8.pm,v 1.2 2002/07/30 17:40:56 gaou Exp $
@@ -39,29 +37,24 @@ use G::Tools::Blast;
 use G::Messenger;
 
 use strict("vars");
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-
-@EXPORT = qw(
-	     rmpolya
-	     redundancy
-	     redundancy_fasta
-	     redundancy_sim4
-	     redundancy_cap3
-             cluster
-	     cap3_parse
-	     blast_parse
-	     sim4_parse
-	     fasta_parse
-	     file_maker  
-	     file_maker_fasta
-	     Totals
-             output_maker
+our @EXPORT = qw(
+		 rmpolya
+		 redundancy
+		 redundancy_fasta
+		 redundancy_sim4
+		 redundancy_cap3
+		 cluster
+		 cap3_parse
+		 blast_parse
+		 sim4_parse
+		 fasta_parse
+		 file_maker  
+		 file_maker_fasta
+		 Totals
+		 output_maker
 );
 
 __DATA__
@@ -956,13 +949,8 @@ sub rmpolya{
     
 }
 
-
-sub DESTROY {
-    my $self = shift;
-}
-
 1;
-__END__
+
 
 
 
