@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: EPCR.pm,v 1.1.1.1 2002/04/02 20:25:44 gaou Exp $
@@ -32,22 +30,12 @@ use SubOpt;
 use G::Messenger;
 use G::Tools::Blast;
 
-BEGIN{
-    eval "use HTTP::Request::Common qw(POST);";
-    if($@){ warn "$@" };
-    eval "use LWP::UserAgent;";
-    if($@){ warn "$@" };
-}
-
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use base qw(Exporter);
+use autouse 'HTTP::Request::Common'=>qw(POST);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
+our @EXPORT = qw(
 	     cognitor
 	     dignitor
 	     set_cogpath
@@ -69,6 +57,8 @@ sub set_cogpath {
 }
 
 sub cognitor {
+    require LWP::UserAgent;
+
     opt_default(hit=>3);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
@@ -183,7 +173,7 @@ Blah blah blah.
 
 =head1 AUTHOR
 
-Kazuharu "Gaou" Arakawa, gaou@g-language.org
+Kazuharu Arakawa, gaou@sfc.keio.ac.jp
 
 =head1 SEE ALSO
 
