@@ -88,10 +88,12 @@ __DATA__
     generated HTML. 
 
   Options:
-    -level     maximum zoom level. (default: 6)
-              This value should be larger than 3.
-              Image width size is 2^(level - 1) * 256, so width at
-              level = 6 is 8192. 
+    -level       maximum zoom level. (default: 6)
+                 This value should be larger than 3.
+                 Image width size is 2^(level - 1) * 256, so width at
+                 level = 6 is 8192. 
+    -javascript  string of javascript code to place within the generated HTML file
+    -posterize   posterize option for ImageMagick (default: 16)
 
   References:
     1. Google Maps API Documentation. http://www.google.com/apis/maps/documentation/
@@ -100,6 +102,7 @@ __DATA__
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
+    20080509-01 added -posterize option
     20070707-01 stopped tiling in the x-direction by default
     20070621-01 initial posting
 
@@ -108,11 +111,12 @@ __DATA__
 
 
 sub generateGMap{
-    opt_default(level=>6, format=>"gif");
+    opt_default(level=>6, format=>"gif", posterize=>16);
     my @argv = opt_get(@_);
     my $file = shift @argv;
     my $level = opt_val("level");
     my $javascript = opt_val("javascript");
+    my $posterize = opt_val("posterize");
     $level = 3 if ($level < 3);
 
     my $filename = basename($file);
@@ -134,7 +138,7 @@ sub generateGMap{
     
     
     if($width == $height){
-	system(sprintf("convert +dither -posterize 16 %s %s/%s.png", $file, $name, $name));
+	system(sprintf("convert +dither -posterize $posterize %s %s/%s.png", $file, $name, $name));
     }else{
 	my ($xdif, $ydif, $size) = (0,0, $width);
 	
@@ -146,7 +150,7 @@ sub generateGMap{
 	    $xdif = int(($height - $width) / 2);
 	}
 	print "HAGE";
-	system(sprintf("convert +dither -posterize 16 -extent %dx%d -roll +%s+%s %s %s/%s.png", $size, $size, $xdif, $ydif, $file, $name, $name));
+	system(sprintf("convert +dither -posterize $posterize -extent %dx%d -roll +%s+%s %s %s/%s.png", $size, $size, $xdif, $ydif, $file, $name, $name));
     }
     chdir($name);
     
@@ -154,8 +158,8 @@ sub generateGMap{
 	my $tiles = 2 ** $i;
 	my $size = $tiles * 256;
 	
-	system(sprintf("convert +dither -posterize 16 %s.png -resize %dx%d level$i.png", $name, $size, $size, $i));
-	system("convert +dither -posterize 16 level$i.png -crop 256x256 level$i-%d.png");
+	system(sprintf("convert +dither -posterize $posterize %s.png -resize %dx%d level$i.png", $name, $size, $size, $i));
+	system("convert +dither -posterize $posterize level$i.png -crop 256x256 level$i-%d.png");
 	
 	for(my $y = 1; $y <= $tiles; $y ++){
 	    for(my $x = 1; $x <= $tiles; $x ++){
