@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: GPAC.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -30,28 +28,17 @@ package G::Tools::GPAC;
 
 use SubOpt;
 use G::Messenger;
-use GD::Graph::bars;
-use Rcmd;
-
-BEGIN{
-    eval "use GD::Graph::bars;";
-    if($@){ warn "$@" };
-}
 
 use strict;
-use Cwd;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use base qw(Exporter);
+use autouse 'Cwd'=>qw(getcwd);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
-	     _acc2ftp_bacteria
-	     gpac
-	     set_gpac
-	     test_gpac
+our @EXPORT = qw(
+		 _acc2ftp_bacteria
+		 gpac
+		 set_gpac
+		 test_gpac
 );
 
 
@@ -214,6 +201,9 @@ sub gpac{
 }
 
 sub test_gpac{
+    require GD::Graph::bars;
+    require Rcmd;
+
     opt_default("stat"=>"t.test", "verbose"=>5, "output"=>"show",
 		"filename"=>"gpac.html", "ptt"=>'');
     my @args = opt_get(@_);
@@ -541,39 +531,4 @@ sub _random_elimination {
 }
 
 
-
-sub DESTROY {
-    my $self = shift;
-}
-
 1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Tools::GPAC - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Tools::PBS;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::GPAC::PBS was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
