@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: $
@@ -32,23 +30,10 @@ use SubOpt;
 use G::Messenger;
 
 use strict;
-
-BEGIN{
-    eval "use LWP::Simple;";
-    if($@){ warn "$@" };
-    eval "use LWP::UserAgent;";
-    if($@){ warn "$@" };
-    eval "use HTTP::Cookies;";
-}
-
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
+our @EXPORT = qw(
 	     PubMedSearch
 	     KeySearch
 );
@@ -61,6 +46,10 @@ __DATA__
 
 
 sub PubMedSearch{
+    require LWP::Simple;
+    require LWP::UserAgent;
+    require HTTP::Cookies;
+    
     my $time=time;
     &opt_default(limit=>500, dir=>'PUBMED'.$time, key=>'');
     my @args=opt_get(@_);
@@ -1215,39 +1204,4 @@ sub WordCount{
     return $count;
 }
 
-
-
-sub DESTROY {
-    my $self = shift;
-}
-
 1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Tools::Literature - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Tools::Literature;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Tools::Literature was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-A. U. Thor, a.u.thor@a.galaxy.far.far.away
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
